==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicTextUI__24BasicCaret.h <==
// public class javax.swing.plaf.basic.BasicTextUI$BasicCaret

// class file dependencies
// @dep_class 553e6310bdd97411 java_awt_Rectangle
// @dep_class 1813bc96181f16e java_awt_geom_Rectangle2D
// @dep_class bfc51dd0f2a7e666 java_awt_geom_RectangularShape
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9ed624a95e4c29e2 javax_swing_plaf_basic_BasicTextUI__24BasicCaret
// @dep_class 3a2d781c2b8e58e2 javax_swing_text_DefaultCaret

// header file dependencies
// @dep_header javax_swing_text_DefaultCaret

#include "javax/swing/text/DefaultCaret.h"

#ifndef _JC_javax_swing_plaf_basic_BasicTextUI__24BasicCaret_H_
#define _JC_javax_swing_plaf_basic_BasicTextUI__24BasicCaret_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$sub_refs	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$refs	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$nonrefs	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$object	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$vmethods	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$vtable	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$vtype	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$object *);

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_geom_RectangularShape$vmethods	java_awt_geom_RectangularShape;
	_jc_java_awt_geom_Rectangle2D$vmethods	java_awt_geom_Rectangle2D;
	_jc_java_awt_Rectangle$vmethods	java_awt_Rectangle;
	_jc_javax_swing_text_DefaultCaret$vmethods	javax_swing_text_DefaultCaret;
	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$vmethods	javax_swing_plaf_basic_BasicTextUI__24BasicCaret;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$refs {
    _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$sub_refs	javax_swing_plaf_basic_BasicTextUI__24BasicCaret;
    _jc_javax_swing_text_DefaultCaret$sub_refs	javax_swing_text_DefaultCaret;
    _jc_java_awt_Rectangle$sub_refs	java_awt_Rectangle;
    _jc_java_awt_geom_Rectangle2D$sub_refs	java_awt_geom_Rectangle2D;
    _jc_java_awt_geom_RectangularShape$sub_refs	java_awt_geom_RectangularShape;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_geom_RectangularShape$sub_nonrefs	java_awt_geom_RectangularShape;
    _jc_java_awt_geom_Rectangle2D$sub_nonrefs	java_awt_geom_Rectangle2D;
    _jc_java_awt_Rectangle$sub_nonrefs	java_awt_Rectangle;
    _jc_javax_swing_text_DefaultCaret$sub_nonrefs	javax_swing_text_DefaultCaret;
    _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$sub_nonrefs	javax_swing_plaf_basic_BasicTextUI__24BasicCaret;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$object {
	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$vtype _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicTextUI__24BasicCaret, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicTextUI__24BasicCaret_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicTextUI__24BasicCaret.h <==
// public class javax.swing.plaf.basic.BasicTextUI$BasicCaret

// class file dependencies
// @dep_class 553e6310bdd97411 java_awt_Rectangle
// @dep_class 1813bc96181f16e java_awt_geom_Rectangle2D
// @dep_class bfc51dd0f2a7e666 java_awt_geom_RectangularShape
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9ed624a95e4c29e2 javax_swing_plaf_basic_BasicTextUI__24BasicCaret
// @dep_class 3a2d781c2b8e58e2 javax_swing_text_DefaultCaret

// header file dependencies
// @dep_header javax_swing_text_DefaultCaret

#include "javax/swing/text/DefaultCaret.h"

#ifndef _JC_javax_swing_plaf_basic_BasicTextUI__24BasicCaret_H_
#define _JC_javax_swing_plaf_basic_BasicTextUI__24BasicCaret_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$sub_refs	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$refs	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$nonrefs	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$object	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$vmethods	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$vtable	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$vtype	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_geom_RectangularShape$vmethods	java_awt_geom_RectangularShape;
	_jc_java_awt_geom_Rectangle2D$vmethods	java_awt_geom_Rectangle2D;
	_jc_java_awt_Rectangle$vmethods	java_awt_Rectangle;
	_jc_javax_swing_text_DefaultCaret$vmethods	javax_swing_text_DefaultCaret;
	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$vmethods	javax_swing_plaf_basic_BasicTextUI__24BasicCaret;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$refs {
    _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$sub_refs	javax_swing_plaf_basic_BasicTextUI__24BasicCaret;
    _jc_javax_swing_text_DefaultCaret$sub_refs	javax_swing_text_DefaultCaret;
    _jc_java_awt_Rectangle$sub_refs	java_awt_Rectangle;
    _jc_java_awt_geom_Rectangle2D$sub_refs	java_awt_geom_Rectangle2D;
    _jc_java_awt_geom_RectangularShape$sub_refs	java_awt_geom_RectangularShape;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_geom_RectangularShape$sub_nonrefs	java_awt_geom_RectangularShape;
    _jc_java_awt_geom_Rectangle2D$sub_nonrefs	java_awt_geom_Rectangle2D;
    _jc_java_awt_Rectangle$sub_nonrefs	java_awt_Rectangle;
    _jc_javax_swing_text_DefaultCaret$sub_nonrefs	javax_swing_text_DefaultCaret;
    _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$sub_nonrefs	javax_swing_plaf_basic_BasicTextUI__24BasicCaret;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$object {
	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$vtype _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicTextUI__24BasicCaret, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicTextUI__24BasicCaret$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicTextUI__24BasicCaret_H_ */
